@@ -21,7 +21,10 @@
 #
 # pylint: disable=W0223
 
+import enum
 import math
+import re
+import sys
 from ipaddress import IPv4Address
 
 from construct import (
@@ -36,6 +39,7 @@ from construct import (
     Enum,
     ExprValidator,
     Float32b,
+    Float64b,
     Int8ub,
     Int16ub,
     Int24ub,
@@ -263,7 +267,7 @@ class Opcode(Construct):
 
 
 class DefaultCountValidator(Adapter):
-    _subcon = Float32b
+    _subcon = Float64b
 
     def __init__(self, subcon, rounding=None, resolution=1.0):
         super().__init__(subcon)
@@ -272,7 +276,7 @@ class DefaultCountValidator(Adapter):
 
     def _decode(self, obj, content, path):
         if obj == (256 ** self.subcon.length) - 1:
-            return None
+            return float(sys.float_info.max)
         else:
             return (
                 round(obj * self.resolution, self.rounding)
@@ -281,7 +285,7 @@ class DefaultCountValidator(Adapter):
             )
 
     def _encode(self, obj, content, path):
-        if obj is None:
+        if obj == float(sys.float_info.max):
             return (256 ** self.subcon.length) - 1
         else:
             return round(obj / self.resolution)
@@ -449,3 +453,45 @@ class NamedSelect(Adapter):
 
     def _encode(self, obj, context, path):
         return obj
+
+
+def camelcase(field_name):
+    if field_name is None:
+        return None
+
+    head, *tail = str(field_name).lower().replace(" ", "_").split("_")
+    return "".join([head, *(i.title() for i in tail)])
+
+
+def snakecase(camel_input):
+    words = re.findall(r"[A-Z]?[a-z]+|[A-Z]{2,}(?=[A-Z][a-z]|\d|\W|$)|\d+", camel_input)
+    return "_".join(map(str.lower, words))
+
+
+def to_case_dict(value, case):
+    if isinstance(value, dict):
+        new_dict = {
+            case(k): to_case_dict(v, case)
+            for k, v in value.items()
+            if not k.startswith("_")
+        }
+        return {value["_name"]: new_dict} if "_name" in value else new_dict
+
+    elif isinstance(value, list):
+        return [to_case_dict(i, case) for i in value]
+
+    elif isinstance(value, enum.Enum):
+        return value.value
+
+    elif isinstance(value, bytes):
+        return value.hex()
+
+    return value
+
+
+def to_camelcase_dict(value):
+    return to_case_dict(value, case=camelcase)
+
+
+def to_snakecase_dict(value):
+    return to_case_dict(value, case=snakecase)
